@@ -167,12 +167,9 @@ class EditorConfigPage(PluginConfigPage):
             rope_label.setWordWrap(True)
         
         sourcecode_group = QGroupBox(_("Source code"))
-        closepar_box = newcb(_("Automatic insertion of parentheses, braces, "
-                                                      "brackets and quotes"),
+        closepar_box = newcb(_("Automatic parentheses, braces and "
+                                     "brackets insertion"),
                              'close_parentheses')
-        add_colons_box = newcb(_("Automatic insertion of colons after 'for', "
-                                                          "'if', 'def', etc"),
-                               'add_colons')
         autounindent_box = newcb(_("Automatic indentation after 'else', "
                                    "'elif', etc."), 'auto_unindent')
         indent_chars_box = self.create_combobox(_("Indentation characters: "),
@@ -267,7 +264,6 @@ class EditorConfigPage(PluginConfigPage):
         sourcecode_layout = QVBoxLayout()
         sourcecode_layout.addWidget(closepar_box)
         sourcecode_layout.addWidget(autounindent_box)
-        sourcecode_layout.addWidget(add_colons_box)
         sourcecode_layout.addWidget(indent_chars_box)
         sourcecode_layout.addWidget(tabwidth_spin)
         sourcecode_layout.addWidget(tab_mode_box)
@@ -958,7 +954,6 @@ class Editor(SpyderPluginWidget):
             ('set_calltips_enabled',                'calltips'),
             ('set_go_to_definition_enabled',        'go_to_definition'),
             ('set_close_parentheses_enabled',       'close_parentheses'),
-            ('set_add_colons_enabled',              'add_colons'),
             ('set_auto_unindent_enabled',           'auto_unindent'),
             ('set_indent_chars',                    'indent_chars'),
             ('set_tab_stop_width',                  'tab_stop_width'),
@@ -1180,10 +1175,11 @@ class Editor(SpyderPluginWidget):
         check_results = editorstack.get_analysis_results()
         self.warning_menu.clear()
         filename = self.get_current_filename()
-        for message, line0, error in check_results:
+        for message, line_number in check_results:
+            error = 'syntax' in message
             text = message[:1].upper()+message[1:]
             icon = get_icon('error.png' if error else 'warning.png')
-            slot = lambda _l=line0: self.load(filename, goto=_l)
+            slot = lambda _l=line_number: self.load(filename, goto=_l)
             action = create_action(self, text=text, icon=icon, triggered=slot)
             self.warning_menu.addAction(action)
             
@@ -1919,8 +1915,6 @@ class Editor(SpyderPluginWidget):
             gotodef_o = self.get_option(gotodef_n)
             closepar_n = 'close_parentheses'
             closepar_o = self.get_option(closepar_n)
-            add_colons_n = 'add_colons'
-            add_colons_o = self.get_option(add_colons_n)
             autounindent_n = 'auto_unindent'
             autounindent_o = self.get_option(autounindent_n)
             indent_chars_n = 'indent_chars'
@@ -1993,8 +1987,6 @@ class Editor(SpyderPluginWidget):
                     editorstack.set_go_to_definition_enabled(gotodef_o)
                 if closepar_n in options:
                     editorstack.set_close_parentheses_enabled(closepar_o)
-                if add_colons_n in options:
-                    editorstack.set_add_colons_enabled(add_colons_o)
                 if autounindent_n in options:
                     editorstack.set_auto_unindent_enabled(autounindent_o)
                 if indent_chars_n in options:
