@@ -42,10 +42,6 @@ import re
 # Keeping a reference to the original sys.exit before patching it
 ORIGINAL_SYS_EXIT = sys.exit
 
-# For debugging purpose only
-STDOUT = sys.stdout
-STDERR = sys.stderr
-
 # Windows platforms only: support for hiding the attached console window
 set_attached_console_visible = None
 is_attached_console_visible = None
@@ -118,7 +114,7 @@ from spyderlib.utils.qthelpers import (create_action, add_actions, get_std_icon,
                                        keybinding, qapplication,
                                        create_python_script_action, file_uri)
 from spyderlib.baseconfig import (get_conf_path, _, get_module_data_path,
-                                  get_module_source_path)
+                                  get_module_source_path, STDOUT, STDERR)
 from spyderlib.config import (get_icon, get_image_path, CONF, get_shortcut,
                               EDIT_EXT, IMPORT_EXT)
 from spyderlib.otherplugins import get_spyderplugins_mods
@@ -359,6 +355,7 @@ class MainWindow(QMainWindow):
         self.already_closed = False
         self.is_starting_up = True
         
+        self.floating_dockwidgets = []
         self.window_size = None
         self.window_position = None
         self.state_before_maximizing = None
@@ -698,8 +695,6 @@ class MainWindow(QMainWindow):
             self.variableexplorer = VariableExplorer(self)
             self.variableexplorer.register_plugin()
 
-        self.extconsole.open_interpreter_at_startup()
-
         if not self.light:
             nsb = self.variableexplorer.add_shellwidget(self.console.shell)
             self.connect(self.console.shell, SIGNAL('refresh()'),
@@ -915,9 +910,16 @@ class MainWindow(QMainWindow):
         """Actions to be performed only after the main window's `show` method 
         was triggered"""
         self.emit(SIGNAL('restore_scrollbar_position()'))
+        self.extconsole.open_interpreter_at_startup()
         self.extconsole.setMinimumHeight(0)
         if self.projectexplorer is not None:
             self.projectexplorer.check_for_io_errors()
+        # [Workaround for Issue 880]
+        # QDockWidget objects are not painted if restored as floating 
+        # windows, so we must dock them before showing the mainwindow,
+        # then set them again as floating windows here.
+        for widget in self.floating_dockwidgets:
+            widget.setFloating(True)
         
     def load_window_settings(self, prefix, default=False, section='main'):
         """Load window layout settings from userconfig-based configuration
@@ -963,6 +965,13 @@ class MainWindow(QMainWindow):
             # Window layout
             if hexstate:
                 self.restoreState( QByteArray().fromHex(str(hexstate)) )
+                # [Workaround for Issue 880]
+                # QDockWidget objects are not painted if restored as floating 
+                # windows, so we must dock them before showing the mainwindow.
+                for widget in self.children():
+                    if isinstance(widget, QDockWidget) and widget.isFloating():
+                        self.floating_dockwidgets.append(widget)
+                        widget.setFloating(False)
             # Is fullscreen?
             if is_fullscreen:
                 self.setWindowState(Qt.WindowFullScreen)
@@ -1012,6 +1021,7 @@ class MainWindow(QMainWindow):
                                          orientation)
             for first, second in ((self.console, self.extconsole),
                                   (self.extconsole, self.historylog),
+
                                   (self.inspector, self.variableexplorer),
                                   (self.variableexplorer, self.onlinehelp),
                                   (self.onlinehelp, self.explorer),
@@ -1256,11 +1266,9 @@ class MainWindow(QMainWindow):
         self.maximize_action.setToolTip(tip)
         
     def maximize_dockwidget(self, restore=False):
-        """
-        Shortcut: Ctrl+Alt+Shift+M
+        """Shortcut: Ctrl+Alt+Shift+M
         First call: maximize current dockwidget
-        Second call (or restore=True): restore original window layout
-        """
+        Second call (or restore=True): restore original window layout"""
         if self.state_before_maximizing is None:
             if restore:
                 return
@@ -1279,6 +1287,11 @@ class MainWindow(QMainWindow):
             #  and the latter won't be refreshed if not visible)
             self.last_plugin.show()
             self.last_plugin.visibility_changed(True)
+            if self.last_plugin is self.editor:
+                # Automatically show the outline if the editor was maximized:
+                self.addDockWidget(Qt.RightDockWidgetArea,
+                                   self.outlineexplorer.dockwidget)
+                self.outlineexplorer.dockwidget.show()
         else:
             # Restore original layout (before maximizing current dockwidget)
             self.last_plugin.dockwidget.setWidget(self.last_plugin)
@@ -1529,7 +1542,8 @@ Please provide any additional information below.
                 if valid:
                     args = unicode(args)
                     if re.match('^--existing --shell=(\d+) --iopub=(\d+) '\
-                                '--stdin=(\d+) --hb=(\d+)$', args):
+                                '--stdin=(\d+) --hb=(\d+)$', args)\
+                       or re.match('^--existing kernel-(\d+).json', args):
                         kernel_name = args
                         break
                 else:
@@ -1550,6 +1564,7 @@ Please provide any additional information below.
             sys.path.insert(1, path)
 
     def remove_path_from_sys_path(self):
+
         """Remove Spyder path from sys.path"""
         sys_path = sys.path
         while sys_path[1] in self.get_spyder_pythonpath():
