@@ -39,7 +39,7 @@ from spyderlib.qt.compat import to_qvariant
 # Local import
 #TODO: Try to separate this module from spyderlib to create a self
 #      consistent editor module (Qt source code and shell widgets library)
-from spyderlib.baseconfig import get_conf_path, _
+from spyderlib.baseconfig import get_conf_path, _, DEBUG
 from spyderlib.config import CONF, get_font, get_icon, get_image_path
 from spyderlib.utils.qthelpers import (add_actions, create_action, keybinding,
                                        mimedata2url)
@@ -51,8 +51,6 @@ from spyderlib.widgets.sourcecode.base import TextEditBaseWidget
 from spyderlib.widgets.sourcecode import syntaxhighlighters
 
 # For debugging purpose:
-STDOUT = sys.stdout
-DEBUG = False
 LOG_FILENAME = get_conf_path('rope.log')
 
 
@@ -132,7 +130,7 @@ class RopeProject(object):
             if DEBUG:
                 t0 = time.time()
             proposals = rope.contrib.codeassist.code_assist(self.project,
-                                                source_code, offset, resource)
+                                    source_code, offset, resource, maxfixes=3)
             proposals = rope.contrib.codeassist.sorted_proposals(proposals)
             if DEBUG:
                 log_dt(LOG_FILENAME, "code_assist/sorted_proposals", t0)
@@ -157,15 +155,15 @@ class RopeProject(object):
                 t0 = time.time()
             cts = rope.contrib.codeassist.get_calltip(
                             self.project, source_code, offset, resource,
-                            ignore_unknown=False, remove_self=True)
+                            ignore_unknown=False, remove_self=True, maxfixes=3)
             if DEBUG:
                 log_dt(LOG_FILENAME, "get_calltip", t0)
             if cts is not None:
                 while '..' in cts:
                     cts = cts.replace('..', '.')
                 try:
-                    doc_text = rope.contrib.codeassist.get_doc(
-                            self.project, source_code, offset, resource)
+                    doc_text = rope.contrib.codeassist.get_doc(self.project,
+                                    source_code, offset, resource, maxfixes=3)
                     if DEBUG:
                         log_dt(LOG_FILENAME, "get_doc", t0)
                 except Exception, _error:
@@ -194,7 +192,7 @@ class RopeProject(object):
             if DEBUG:
                 t0 = time.time()
             resource, lineno = rope.contrib.codeassist.get_definition_location(
-                            self.project, source_code, offset, resource)
+                    self.project, source_code, offset, resource, maxfixes=3)
             if DEBUG:
                 log_dt(LOG_FILENAME, "get_definition_location", t0)
             if resource is not None:
